==> applet-service-1.0.0-vg-20210601.074250-8-sources.jar: com/bizvane/appletservice/models/vo/ActivityRedPacketVo.java <==
package com.bizvane.appletservice.models.vo;

import com.bizvane.centerstageservice.models.po.SysStorePo;
import com.bizvane.couponfacade.models.po.CouponDefinitionPO;
import com.bizvane.mktcenterservice.models.po.MktActivityPOWithBLOBs;
import com.bizvane.mktcenterservice.models.po.MktActivityRedPacketPO;
import com.bizvane.mktcenterservice.models.vo.AndActivityRedPacketZhuliRecordVO;

import java.util.List;

public class ActivityRedPacketVo {
    //主表
    private MktActivityPOWithBLOBs activityPO;
    //奖励
    private MktActivityRedPacketPO activityRedPacketPO;

    private List<SysStorePo> storeList;

    private CouponDefinitionPO couponDefinitionPO;

    private String wxNickname;

    private String wxHeadUrl;
    //拆红包状态
    private Integer openRedEnvel;
    //助力状态
    private Integer assistanceRedEnvel;
    //发起状态
    private Integer launchRedEnvel;
    private Integer orgGrede;
    private String memberCode;
    private Long mktTraceId;

    private AndActivityRedPacketZhuliRecordVO andActivityRedPacketZhuliRecordVO;

    public MktActivityPOWithBLOBs getActivityPO() {
        return activityPO;
    }

    public void setActivityPO(MktActivityPOWithBLOBs activityPO) {
        this.activityPO = activityPO;
    }

    public MktActivityRedPacketPO getActivityRedPacketPO() {
        return activityRedPacketPO;
    }

    public void setActivityRedPacketPO(MktActivityRedPacketPO activityRedPacketPO) {
        this.activityRedPacketPO = activityRedPacketPO;
    }

    public List<SysStorePo> getStoreList() {
        return storeList;
    }

    public void setStoreList(List<SysStorePo> storeList) {
        this.storeList = storeList;
    }

    public CouponDefinitionPO getCouponDefinitionPO() {
        return couponDefinitionPO;
    }

    public void setCouponDefinitionPO(CouponDefinitionPO couponDefinitionPO) {
        this.couponDefinitionPO = couponDefinitionPO;
    }

    public String getWxNickname() {
        return wxNickname;
    }

    public void setWxNickname(String wxNickname) {
        this.wxNickname = wxNickname;
    }

    public String getWxHeadUrl() {
        return wxHeadUrl;
    }

    public void setWxHeadUrl(String wxHeadUrl) {
        this.wxHeadUrl = wxHeadUrl;
    }

    public Integer getOpenRedEnvel() {
        return openRedEnvel;
    }

    public void setOpenRedEnvel(Integer openRedEnvel) {
        this.openRedEnvel = openRedEnvel;
    }

    public Integer getAssistanceRedEnvel() {
        return assistanceRedEnvel;
    }

    public void setAssistanceRedEnvel(Integer assistanceRedEnvel) {
        this.assistanceRedEnvel = assistanceRedEnvel;
    }

    public Integer getLaunchRedEnvel() {
        return launchRedEnvel;
    }

    public void setLaunchRedEnvel(Integer launchRedEnvel) {
        this.launchRedEnvel = launchRedEnvel;
    }

    public Integer getOrgGrede() {
        return orgGrede;
    }

    public void setOrgGrede(Integer orgGrede) {
        this.orgGrede = orgGrede;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Long getMktTraceId() {
        return mktTraceId;
    }

    public void setMktTraceId(Long mktTraceId) {
        this.mktTraceId = mktTraceId;
    }

    public AndActivityRedPacketZhuliRecordVO getAndActivityRedPacketZhuliRecordVO() {
        return andActivityRedPacketZhuliRecordVO;
    }

    public void setAndActivityRedPacketZhuliRecordVO(AndActivityRedPacketZhuliRecordVO andActivityRedPacketZhuliRecordVO) {
        this.andActivityRedPacketZhuliRecordVO = andActivityRedPacketZhuliRecordVO;
    }
}

==> applet-service-1.5.2-vg-20220719.041856-3-sources.jar: com/bizvane/appletservice/models/vo/ActivityRedPacketVo.java <==
package com.bizvane.appletservice.models.vo;

import com.bizvane.centerstageservice.models.po.SysStorePo;
import com.bizvane.couponfacade.models.po.CouponDefinitionPO;
import com.bizvane.mktcenterservice.models.po.MktActivityPOWithBLOBs;
import com.bizvane.mktcenterservice.models.po.MktActivityRedPacketPO;
import com.bizvane.mktcenterservice.models.po.MktMaterialPO;
import com.bizvane.mktcenterservice.models.vo.AndActivityRedPacketZhuliRecordVO;

import java.util.List;

public class ActivityRedPacketVo {
    //主表
    private MktActivityPOWithBLOBs activityPO;
    //奖励
    private MktActivityRedPacketPO activityRedPacketPO;

    //素材
    private List<MktMaterialPO> mktMaterialPOList;

    private List<SysStorePo> storeList;

    private CouponDefinitionPO couponDefinitionPO;

    private String wxNickname;

    private String wxHeadUrl;
    //拆红包状态
    private Integer openRedEnvel;
    //助力状态
    private Integer assistanceRedEnvel;
    //发起状态
    private Integer launchRedEnvel;
    private Integer orgGrede;
    private String memberCode;
    private Long mktTraceId;

    private AndActivityRedPacketZhuliRecordVO andActivityRedPacketZhuliRecordVO;

    public MktActivityPOWithBLOBs getActivityPO() {
        return activityPO;
    }

    public void setActivityPO(MktActivityPOWithBLOBs activityPO) {
        this.activityPO = activityPO;
    }

    public MktActivityRedPacketPO getActivityRedPacketPO() {
        return activityRedPacketPO;
    }

    public void setActivityRedPacketPO(MktActivityRedPacketPO activityRedPacketPO) {
        this.activityRedPacketPO = activityRedPacketPO;
    }

    public List<SysStorePo> getStoreList() {
        return storeList;
    }

    public void setStoreList(List<SysStorePo> storeList) {
        this.storeList = storeList;
    }

    public CouponDefinitionPO getCouponDefinitionPO() {
        return couponDefinitionPO;
    }

    public void setCouponDefinitionPO(CouponDefinitionPO couponDefinitionPO) {
        this.couponDefinitionPO = couponDefinitionPO;
    }

    public String getWxNickname() {
        return wxNickname;
    }

    public void setWxNickname(String wxNickname) {
        this.wxNickname = wxNickname;
    }

    public String getWxHeadUrl() {
        return wxHeadUrl;
    }

    public void setWxHeadUrl(String wxHeadUrl) {
        this.wxHeadUrl = wxHeadUrl;
    }

    public Integer getOpenRedEnvel() {
        return openRedEnvel;
    }

    public void setOpenRedEnvel(Integer openRedEnvel) {
        this.openRedEnvel = openRedEnvel;
    }

    public Integer getAssistanceRedEnvel() {
        return assistanceRedEnvel;
    }

    public void setAssistanceRedEnvel(Integer assistanceRedEnvel) {
        this.assistanceRedEnvel = assistanceRedEnvel;
    }

    public Integer getLaunchRedEnvel() {
        return launchRedEnvel;
    }

    public void setLaunchRedEnvel(Integer launchRedEnvel) {
        this.launchRedEnvel = launchRedEnvel;
    }

    public Integer getOrgGrede() {
        return orgGrede;
    }

    public void setOrgGrede(Integer orgGrede) {
        this.orgGrede = orgGrede;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Long getMktTraceId() {
        return mktTraceId;
    }

    public void setMktTraceId(Long mktTraceId) {
        this.mktTraceId = mktTraceId;
    }

    public AndActivityRedPacketZhuliRecordVO getAndActivityRedPacketZhuliRecordVO() {
        return andActivityRedPacketZhuliRecordVO;
    }

    public void setAndActivityRedPacketZhuliRecordVO(AndActivityRedPacketZhuliRecordVO andActivityRedPacketZhuliRecordVO) {
        this.andActivityRedPacketZhuliRecordVO = andActivityRedPacketZhuliRecordVO;
    }

    public List<MktMaterialPO> getMktMaterialPOList() {
        return mktMaterialPOList;
    }

    public void setMktMaterialPOList(List<MktMaterialPO> mktMaterialPOList) {
        this.mktMaterialPOList = mktMaterialPOList;
    }
}
